TemplateEngine

Struct TemplateEngine 

pub struct TemplateEngine { /* private fields */ }
Represents a template engine.

Examples

use crabtml::TemplateEngine;
let engine = TemplateEngine::new();

Implementations

Source

impl TemplateEngine

pub fn new() -> TemplateEngine

Creates a new TemplateEngine.

pub fn add_template_from_file<P: AsRef<Path>>( &mut self, name: &str, pathname: P, ) -> Result<(), Box<dyn Error>>

Adds a template from a file path to the template engine.

Examples
use crabtml::TemplateEngine;
let mut engine = TemplateEngine::new();
engine.add_template_from_file("test", "tests/test.html").unwrap();
assert!(!engine.is_empty());
pub fn add_template_from_string( &mut self, name: &str, template: &str, ) -> Result<(), Box<dyn Error>>

Adds a template from a string to the template engine.

Examples
use crabtml::TemplateEngine;
let mut engine = TemplateEngine::new();
engine.add_template_from_string("test", "hello {{ text }}").unwrap();
assert!(!engine.is_empty());
pub fn render( &self, name: &str, context: &mut Context, ) -> Result<String, Box<dyn Error>>

Renders a template.

Examples
use crabtml::{Context, TemplateEngine};

let mut engine = TemplateEngine::new();
engine
    .add_template_from_string("test", "hello {{ text }}")
    .unwrap();
let mut context = Context::new();
context.set("text", "darkness my old friend");
let rendered = engine.render("test", &mut context).unwrap();
assert_eq!(rendered, "hello darkness my old friend");
pub fn is_empty(&self) -> bool

Checks if the template engine is empty, i.e. has no templates.

Examples
use crabtml::TemplateEngine;
let engine = TemplateEngine::new();
assert!(engine.is_empty());